from ._group import snake_zrb_app_name_microservices_group
from .deploy import deploy_snake_zrb_app_name_microservices
from .start import start_snake_zrb_app_name_microservices

assert snake_zrb_app_name_microservices_group
assert deploy_snake_zrb_app_name_microservices
assert start_snake_zrb_app_name_microservices
