from zrb import BoolInput

enable_monitoring_input = BoolInput(
    name="enable-kebab-zrb-app-name-monitoring",
    description='Enable "kebab-zrb-app-name" monitoring',
    prompt='Enable "kebab-zrb-app-name" monitoring?',
    default=False,
)
