from zrb.builtin.project.add.fastapp._group import project_add_fastapp_group
from zrb.builtin.project.add.fastapp.app import add_fastapp_application
from zrb.builtin.project.add.fastapp.crud import add_fastapp_crud
from zrb.builtin.project.add.fastapp.field import add_fastapp_field
from zrb.builtin.project.add.fastapp.module import add_fastapp_module

assert project_add_fastapp_group
assert add_fastapp_application
assert add_fastapp_module
assert add_fastapp_crud
assert add_fastapp_field
