from zrb import StrInput

image_input = StrInput(
    name="kebab-zrb-app-name-image",
    description='Image name of "kebab-zrb-app-name"',
    prompt='Image name of "kebab-zrb-app-name"',
    default="zrb-app-image-name:latest",
)
