from zrb.helper.accessories.color import colored
from zrb.helper.log import logger

logger.debug(colored("Loading zrb.task_env.constant", attrs=["dark"]))

RESERVED_ENV_NAMES = ("_ZRB_EXECUTION_ID", "_ZRB_EXECUTION_ID")
