from zrb.builtin.ubuntu.install._group import ubuntu_install_group
from zrb.builtin.ubuntu.install.all import install_ubuntu_all
from zrb.builtin.ubuntu.install.essentials import install_ubuntu_essentials
from zrb.builtin.ubuntu.install.tex import install_ubuntu_tex
from zrb.builtin.ubuntu.install.toys import install_ubuntu_toys

assert ubuntu_install_group
assert install_ubuntu_all
assert install_ubuntu_essentials
assert install_ubuntu_tex
assert install_ubuntu_toys
