from zrb.builtin.project.add.app._group import project_add_app_group
from zrb.builtin.project.add.app.generator import add_app_generator
from zrb.builtin.project.add.app.python import add_python_app

assert project_add_app_group
assert add_app_generator
assert add_python_app
