from zrb.task_input.str_input import StrInput

module_name_input = StrInput(
    name="module-name",
    shortcut="m",
    description="module name",
    prompt="module name",
    default="library",
)
