from zrb.builtin.base64._group import base64_group
from zrb.builtin.base64.decode import decode_base64
from zrb.builtin.base64.encode import encode_base64

assert base64_group
assert decode_base64
assert encode_base64
