from ._group import snake_zrb_app_name_frontend_group
from .build import build_snake_zrb_app_name_frontend
from .build_once import build_snake_zrb_app_name_frontend_once

assert snake_zrb_app_name_frontend_group
assert build_snake_zrb_app_name_frontend
assert build_snake_zrb_app_name_frontend_once
